(create this context entity-config)Returns a new instance of this entity type, based on the provided entity-config and context.
The returned instance should be a ThreeJS Object3D or one of its sub-classes.
Returns a new instance of this entity type, based on the provided `entity-config` and `context`. The returned instance should be a ThreeJS `Object3D` or one of its sub-classes.
(destroy! this context object entity-config)Destroys an existing instance of this entity type.
Destroys an existing instance of this entity type.
(update! this context object new-entity-config)Updates an existing instance of this entity entity type in-place, based on the provided
new-entity-config and context.
Updates an existing instance of this entity entity type in-place, based on the provided `new-entity-config` and `context`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |