ClojureScript only.

threeagent.impl.scene


effective-cameracljs

(effective-camera sctx)

Returns the camera override if set, otherwise the scene-managed camera.

Returns the camera override if set, otherwise the scene-managed camera.
sourceraw docstring

rendercljs

(render root-fn dom-root config)
source

cljdoc builds & hosts documentation for Clojure/Script libraries