threeagent.impl.frame-pacer


createcljs

(create max-fps min-fps)

Create a new frame pacer. max-fps can be nil (no cap). min-fps defaults to 10.

Create a new frame pacer. max-fps can be nil (no cap). min-fps defaults to 10.
sourceraw docstring

infocljs

(info pacer)

Return a snapshot of the pacer's current state.

Return a snapshot of the pacer's current state.
sourceraw docstring

record-render-time!cljs

(record-render-time! pacer render-ms)

Record a render time sample and evaluate tier changes.

Record a render time sample and evaluate tier changes.
sourceraw docstring

reset-pacer!cljs

(reset-pacer! pacer max-fps min-fps)

Reset the pacer, restarting calibration with new parameters.

Reset the pacer, restarting calibration with new parameters.
sourceraw docstring

should-render?cljs

(should-render? pacer now)

Returns true if this frame should be rendered. Call once per animation frame.

Returns true if this frame should be rendered. Call once per animation frame.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries