(create max-fps min-fps)Create a new frame pacer. max-fps can be nil (no cap). min-fps defaults to 10.
Create a new frame pacer. max-fps can be nil (no cap). min-fps defaults to 10.
(info pacer)Return a snapshot of the pacer's current state.
Return a snapshot of the pacer's current state.
(record-render-time! pacer render-ms)Record a render time sample and evaluate tier changes.
Record a render time sample and evaluate tier changes.
(reset-pacer! pacer max-fps min-fps)Reset the pacer, restarting calibration with new parameters.
Reset the pacer, restarting calibration with new parameters.
(should-render? pacer now)Returns true if this frame should be rendered. Call once per animation frame.
Returns true if this frame should be rendered. Call once per animation frame.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |