(effective-camera sctx)Returns the camera override if set, otherwise the scene-managed camera.
Returns the camera override if set, otherwise the scene-managed camera.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |